### 0.9.5

```{rubric} Bug fixes
```
* {func}`~rapids_singlecell.tl.louvain` now has backward compatibility with older rapids versions {pr}`114` {smaller}`S Dicks`

```{rubric} Misc
```
* Updates Conda yaml file to work with rapids-23.12 {pr}`114` {smaller}`S Dicks`
